Module extension

Module extension 

Functions

detect_image_format_from_extension
Detects an image format from a file extension.
extension_from_filename
Extracts a filename extension without changing its original case.
image_extension
Returns the canonical extension without a leading dot.
is_image_extension
Returns true when the input is a known image extension.
normalize_extension
Normalizes an image extension to a canonical lowercase value without a dot.