Module format

Module format 

Structs

ImageMetadata
Small image metadata bundle for callers that already know or discovered a format.

Enums

ImageFormat
Common image formats handled by this crate.
ImageKind
Broad classification for image container types.

Functions

image_kind
Returns the broad image kind for a format.
is_raster_image
Returns true when the format is raster-based.
is_vector_image
Returns true when the format is vector-based.
is_web_image_format
Returns true for formats commonly used in browsers and web asset pipelines.
supports_animation
Returns true when the format commonly supports animation.
supports_transparency
Returns true when the format can commonly carry transparency.