pub const fn is_web_image_format(format: ImageFormat) -> boolExpand description
Returns true for formats commonly used in browsers and web asset pipelines.
pub const fn is_web_image_format(format: ImageFormat) -> boolReturns true for formats commonly used in browsers and web asset pipelines.