pub struct ImageMetadata {
pub format: ImageFormat,
pub kind: ImageKind,
pub mime_type: Option<&'static str>,
pub extension: Option<&'static str>,
pub size: Option<ImageSize>,
}Expand description
Small image metadata bundle for callers that already know or discovered a format.
Fields
format: ImageFormatkind: ImageKindmime_type: Option<&'static str>extension: Option<&'static str>size: Option<ImageSize>Implementations
Sourceimpl ImageMetadata
impl ImageMetadata
Sourcepub fn new(format: ImageFormat) -> Self
pub fn new(format: ImageFormat) -> Self
Builds metadata from a detected format without embedded size information.
Sourcepub fn with_size(format: ImageFormat, size: Option<ImageSize>) -> Self
pub fn with_size(format: ImageFormat, size: Option<ImageSize>) -> Self
Builds metadata from a detected format and optional size information.