pub fn detect_image_format_from_bytes(bytes: &[u8]) -> ImageFormatExpand description
Detects an image format from common magic bytes without fully parsing the file.
pub fn detect_image_format_from_bytes(bytes: &[u8]) -> ImageFormatDetects an image format from common magic bytes without fully parsing the file.