Module size

Module size 

Structs

ImageSize
Basic image dimensions.

Functions

cover_size
Scales a size so it fully covers bounds, preserving aspect ratio.
fit_within
Scales a size to fit completely within bounds, preserving aspect ratio.
scale_to_height
Scales a size to an exact height and rounded matching width.
scale_to_width
Scales a size to an exact width and rounded matching height.