Functions
- detect_
image_ format_ from_ extension - Detects an image format from a file extension.
- extension_
from_ filename - Extracts a filename extension without changing its original case.
- image_
extension - Returns the canonical extension without a leading dot.
- is_
image_ extension - Returns true when the input is a known image extension.
- normalize_
extension - Normalizes an image extension to a canonical lowercase value without a dot.